//==========================================================================
//#include "JMP.h"
//
// Author: SAS Institute, Inc.
// Copyright: None.
//
// The file JMP.h is provided by SAS Institute as part of the "AutoClient" 
// automation sample for Visual C++, which is included with JMP.
// For a typical JMP installation, this file can be found at:
// <JMP Installation Directory>\Support Files English\Automation Samples\Visual C++ Sample\AutoClient
//
// No copyrights are violated by including this file in your Visual Studio 
// project.
//
// JMP(c) is a product of SAS Institute, Inc.
//==========================================================================
#ifndef JMP_H
#define JMP_H 1

// IJMPAutoApp wrapper class
class IJMPAutoApp : public COleDispatchDriver
{
public:
	IJMPAutoApp() {}		// Calls COleDispatchDriver default constructor
	IJMPAutoApp(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IJMPAutoApp(const IJMPAutoApp& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	BOOL GetVisible();
	void SetVisible(BOOL);
	BOOL GetToolsVisible();
	void SetToolsVisible(BOOL);
	LPDISPATCH GetApplication();
	void SetApplication(LPDISPATCH);
	LPDISPATCH GetParent();
	void SetParent(LPDISPATCH);
	CString GetName();
	void SetName(LPCTSTR);
	CString GetFullName();
	void SetFullName(LPCTSTR);

// Operations
public:
	void Quit();
	void RunCommand(LPCTSTR pCommand);
	LPDISPATCH OpenDocument(LPCTSTR pszName);
	LPDISPATCH CreateTextImportObject(LPCTSTR pszName, long nColumns);
	LPDISPATCH NewDataTable(LPCTSTR filename);
	LPDISPATCH NewDatabaseObject();
	LPDISPATCH NewDataFeed();
	BOOL RunJSLFile(LPCTSTR filePath);
	short GetNumberOfAutomationDatatables();
	CString GetTableNameFromIndex(short index);
	LPDISPATCH GetTableHandleFromIndex(short index);
	LPDISPATCH GetTableHandleFromName(LPCTSTR Name);
	BOOL SetCurrentDirectory(LPCTSTR dirName);
	void CloseAllWindows();
	void CloseWindowsOfType(long windowType);
	LPDISPATCH InternetOpenItem(LPCTSTR URL, long openHow);
	void Activate();
};
/////////////////////////////////////////////////////////////////////////////
// IJMPDoc wrapper class

class IJMPDoc : public COleDispatchDriver
{
public:
	IJMPDoc() {}		// Calls COleDispatchDriver default constructor
	IJMPDoc(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IJMPDoc(const IJMPDoc& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	BOOL GetVisible();
	void SetVisible(BOOL);
	BOOL GetAutoSave();
	void SetAutoSave(BOOL);
	LPDISPATCH GetApplication();
	void SetApplication(LPDISPATCH);
	LPDISPATCH GetParent();
	void SetParent(LPDISPATCH);
	CString GetName();
	void SetName(LPCTSTR);
	CString GetFullName();
	void SetFullName(LPCTSTR);
	CString GetPath();
	void SetPath(LPCTSTR);
	SCODE GetSaved();
	void SetSaved(SCODE);

// Operations
public:
	void CopyToClipboard();
	LPDISPATCH GetDataTable();
	void Save();
	void SaveAs(LPCTSTR filename);
	void Close(BOOL saveChanges, LPCTSTR filename);
	void Activate();
	LPDISPATCH CreateCluster();
	LPDISPATCH CreateBivariate();
	LPDISPATCH CreateOneway();
	LPDISPATCH CreateContingency();
	LPDISPATCH CreateDistribution();
	LPDISPATCH CreateMultivariate();
	LPDISPATCH CreateControlChart();
	LPDISPATCH CreateOverlayPlot();
	LPDISPATCH CreateLogistic();
	LPDISPATCH CreateSurvival();
	LPDISPATCH CreateMatchedPairs();
	LPDISPATCH CreateSpinPlot();
	LPDISPATCH CreatePareto();
	LPDISPATCH CreateTimeSeries();
	LPDISPATCH CreateTernary();
	LPDISPATCH CreateProfiler();
	LPDISPATCH CreateContourProfiler();
	LPDISPATCH CreateContourPlot();
	LPDISPATCH CreateRecurrence();
	LPDISPATCH CreateVariabilityChart();
	LPDISPATCH CreateChart();
	LPDISPATCH CreateFitModel();
	LPDISPATCH CreatePLS();
	LPDISPATCH CreateDiagram();
	LPDISPATCH CreateDiscriminant();
	LPDISPATCH CreateNeural();
};
/////////////////////////////////////////////////////////////////////////////
// IAutoDataTable wrapper class

class IAutoDataTable : public COleDispatchDriver
{
public:
	IAutoDataTable() {}		// Calls COleDispatchDriver default constructor
	IAutoDataTable(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoDataTable(const IAutoDataTable& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	BOOL GetVisible();
	void SetVisible(BOOL);
	long GetNumberRows();
	void SetNumberRows(long);
	LPDISPATCH GetDocument();
	void SetDocument(LPDISPATCH);
	long GetNumberColumns();
	void SetNumberColumns(long);

// Operations
public:
	LPDISPATCH NewColumn(LPCTSTR Name, long DataType, long ModelType, short width);
	long AddRows(short NumToAdd, long AddAfter);
	BOOL AddToSortList(LPCTSTR Name, BOOL bAscending);
	BOOL AddToSubList(LPCTSTR Name);
	LPDISPATCH Sort(BOOL fReplace);
	LPDISPATCH Subset();
	void DeleteColumn(LPCTSTR Name);
	LPDISPATCH GetColumn(LPCTSTR Name);
	void SelectRows(long startRow, long endRow);
	BOOL DeleteSelectedRows();
	short AddColumns(LPCTSTR prefix, short NumToAdd, short where, long type, short FieldWidth);
	BOOL AddToConcatList();
	LPDISPATCH Concatenate();
	BOOL AddToSummaryGroup(LPCTSTR Name);
	BOOL AddToSummarySubGroup(LPCTSTR Name);
	BOOL AddToSummaryStatList(LPCTSTR Name, long stat);
	LPDISPATCH Summary();
	void AddStringTableVar(LPCTSTR varName, LPCTSTR value);
	void AddNumericTableVar(LPCTSTR varName, double value);
	CString GetColumnName(long colNumber);
	LPDISPATCH GetColumnByIndex(long index);
	LPDISPATCH Transpose();
	BOOL AddToStackList(LPCTSTR Name);
	BOOL SetStackOptions(BOOL StackByRow, BOOL EliminateMissing, BOOL DropOtherCols);
	LPDISPATCH Stack(LPCTSTR idColName, LPCTSTR stackedColName, LPCTSTR tableName);
	BOOL AddToJoinList(LPCTSTR Name);
	LPDISPATCH Join(LPDISPATCH dataTable2, long joinType, LPCTSTR outputTableName);
	BOOL AddToSplitList(LPCTSTR Name);
	BOOL AddToSplitGroupList(LPCTSTR Name);
	LPDISPATCH Split(LPCTSTR columnIDName, LPCTSTR outputTableName, BOOL keepRemainingCols);
	VARIANT JSLFunction(LPCTSTR fnText);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL Activate();
	BOOL PrintTable();
	BOOL ReorderColumns(long how);
	BOOL ExcludeSelectedRows();
	BOOL LabelSelectedRows();
	BOOL HideSelectedRows();
	BOOL ClearSelectedRowStates();
	BOOL ClearRowsSelection();
	BOOL SelectRowsWhere(LPCTSTR columnName, long operation, long selectHow, LPCTSTR comparative);
	BOOL SelectHiddenRows();
	BOOL SelectExcludedRows();
	BOOL SelectLabeledRows();
	BOOL SelectAllRows();
	BOOL InvertRowSelections();
	long GetNumberOfRowsByRowState(long stateToCheck);
	BOOL AddToSummaryGroupWithOrder(LPCTSTR Name, long descending);
	BOOL SummarySpecifyQuantiles(double quantiles);
	long EnumRowStatesBegin(long stateToCheck);
	long EnumRowStatesGetNextRow();
	long EnumRowStatesGetRowByIndex(long indexIntoEnumerator);
	BOOL CheckRowState(long rowNumber, long stateToCheck);
	BOOL GetRowStatesChanged();
	void SetJoinOptions(BOOL UpdateFirstTable, BOOL CopyFormulas, BOOL SuppressFormulaEval);
	void AddToJoinMatchList(LPCTSTR Name);
	void SetJoinMatchOptions(BOOL DropMultiples, BOOL IncludeNonMatches);
	void SummarySetStatColumnFormat(long format);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoColumn wrapper class

class IAutoColumn : public COleDispatchDriver
{
public:
	IAutoColumn() {}		// Calls COleDispatchDriver default constructor
	IAutoColumn(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoColumn(const IAutoColumn& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	long GetNumberRows();
	void SetNumberRows(long);
	CString GetName();
	void SetName(LPCTSTR);
	long GetModelType();
	void SetModelType(long);
	short GetFieldWidth();
	void SetFieldWidth(short);
	short GetNumDecPlaces();
	void SetNumDecPlaces(short);
	long GetOutputFormat();
	void SetOutputFormat(long);
	long GetInputFormat();
	void SetInputFormat(long);
	BOOL GetLocked();
	void SetLocked(BOOL);
	long GetDataType();
	void SetDataType(long);

// Operations
public:
	void SetCellVal(long nRow, LPCTSTR pValue);
	CString GetCellVal(long RowNum);
	void AddFormula(LPCTSTR formula);
	long GetDataSource();
	long GetValidation();
	BOOL SetRole(long RoleType);
	BOOL Exclude();
	BOOL Label();
	BOOL Hide();
	BOOL ScrollLock();
	CString GetFormula();
	BOOL RemoveFormula();
};
/////////////////////////////////////////////////////////////////////////////
// IAutoCluster wrapper class

class IAutoCluster : public COleDispatchDriver
{
public:
	IAutoCluster() {}		// Calls COleDispatchDriver default constructor
	IAutoCluster(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoCluster(const IAutoCluster& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	void MarkClusters(BOOL flag);
	void ColorClusters(BOOL flag);
	void NumClusters(long number);
	void SaveClusters();
	void SaveDisplayOrder();
	BOOL SaveClusterHierarchy();
	BOOL SetOrientation(long orientation);
	BOOL ColorMap(long mapType);
	BOOL GeometricXScale(BOOL flag);
	BOOL DistanceGraph(BOOL flag);
	void KMGo();
	void KMStep();
	void KMWithinClusterStdDev(BOOL flag);
	void KMShiftDistances(BOOL flag);
	BOOL StandardizeData(BOOL flag);
	BOOL LaunchAddColumn(LPCTSTR Name);
	BOOL LaunchRemoveColumn(LPCTSTR Name);
	BOOL Launch();
	void LaunchSpecifyKMeans(BOOL flag);
	void LaunchSpecifyDistanceFormula(long formulaConst);
	void LaunchAddJSL(LPCTSTR JSL);
	BOOL LaunchAddWeight(LPCTSTR Name);
	BOOL LaunchAddFreq(LPCTSTR Name);
	BOOL LaunchAddBy(LPCTSTR Name);
	BOOL LaunchRemoveFreq(LPCTSTR Name);
	BOOL LaunchRemoveWeight(LPCTSTR Name);
	BOOL LaunchRemoveBy(LPCTSTR Name);
	BOOL KMSaveMixtureProbs();
	BOOL KMSaveMixtureFormulas();
	BOOL KMSeedWithSelectedRows();
	BOOL KMSimulateMixtures(long numberOfRows);
	BOOL KMBiplot(BOOL flag);
	BOOL KMNormalMixtures(BOOL flag);
	BOOL KMSOM(BOOL flag);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoJournal wrapper class

class IAutoJournal : public COleDispatchDriver
{
public:
	IAutoJournal() {}		// Calls COleDispatchDriver default constructor
	IAutoJournal(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoJournal(const IAutoJournal& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:

// Operations
public:
	BOOL SaveAsHTML(LPCTSTR filename, long graphicType);
	BOOL SaveAsRTF(LPCTSTR filename, long graphicType);
	BOOL SaveAsJournal(LPCTSTR filename);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoBivar wrapper class

class IAutoBivar : public COleDispatchDriver
{
public:
	IAutoBivar() {}		// Calls COleDispatchDriver default constructor
	IAutoBivar(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoBivar(const IAutoBivar& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	void ShowPoints(BOOL flag);
	LPDISPATCH FitMean();
	LPDISPATCH FitLine();
	LPDISPATCH FitPolynomial(double degree);
	LPDISPATCH FitSpline(double degree);
	LPDISPATCH FitEachValue();
	void DensityEllipses(double degree);
	LPDISPATCH NonParDensity();
	void PolygonGate();
	BOOL LaunchAddX(LPCTSTR Name);
	BOOL LaunchAddY(LPCTSTR Name);
	BOOL Launch();
	BOOL LaunchAddFreq(LPCTSTR Name);
	BOOL LaunchAddWeight(LPCTSTR Name);
	BOOL LaunchAddBy(LPCTSTR Name);
	void LaunchAddJSL(LPCTSTR JSL);
	BOOL LaunchRemoveX(LPCTSTR Name);
	BOOL LaunchRemoveY(LPCTSTR Name);
	BOOL LaunchRemoveWeight(LPCTSTR Name);
	BOOL LaunchRemoveFreq(LPCTSTR Name);
	BOOL LaunchRemoveBy(LPCTSTR Name);
	LPDISPATCH FitOrthogonal(long fitType, double varianceRatio);
	LPDISPATCH FitTransformed(long XTransform, long YTransform, short PolyDegree);
	BOOL GroupBy(LPCTSTR columnName);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoFit wrapper class

class IAutoFit : public COleDispatchDriver
{
public:
	IAutoFit() {}		// Calls COleDispatchDriver default constructor
	IAutoFit(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoFit(const IAutoFit& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:

// Operations
public:
	void ConfidenceFit(BOOL flag);
	void ConfidenceIndividual(BOOL flag);
	void LineOfFit(BOOL flag);
	void SavePredicteds();
	void SaveResiduals();
	void PlotResiduals(BOOL flag);
	void SetAlpha(double alpha);
	void RemoveFit();
};
/////////////////////////////////////////////////////////////////////////////
// IAutoFitDensity wrapper class

class IAutoFitDensity : public COleDispatchDriver
{
public:
	IAutoFitDensity() {}		// Calls COleDispatchDriver default constructor
	IAutoFitDensity(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoFitDensity(const IAutoFitDensity& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:

// Operations
public:
	void KernelControl(BOOL flag);
	void FivePercentContours(BOOL flag);
	void MeshPlot(BOOL flag);
	void ModelClustering(BOOL flag);
	LPDISPATCH SaveDensityGrid();
};
/////////////////////////////////////////////////////////////////////////////
// IAutoOneway wrapper class

class IAutoOneway : public COleDispatchDriver
{
public:
	IAutoOneway() {}		// Calls COleDispatchDriver default constructor
	IAutoOneway(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoOneway(const IAutoOneway& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	void quantiles(BOOL flag);
	void MeansAnovaT(BOOL flag);
	void MeansStdDev(BOOL flag);
	void UnequalVariances(BOOL flag);
	void SetAlpha(double level);
	void NormalQuantilePlot(BOOL flag);
	void NormalQuantilePlotQbyA(BOOL flag);
	void NormalQuantileLineOfFit(BOOL flag);
	void NormalQuantileProbLabels(BOOL flag);
	void Save(long option);
	void Nonparametric(long option, BOOL flag);
	void CompareMeans(long option, BOOL flag);
	void DisplayOptions(long option, BOOL flag);
	BOOL LaunchAddX(LPCTSTR Name);
	BOOL LaunchAddY(LPCTSTR Name);
	BOOL LaunchAddWeight(LPCTSTR Name);
	BOOL LaunchAddFreq(LPCTSTR Name);
	BOOL LaunchAddBlock(LPCTSTR Name);
	BOOL LaunchAddBy(LPCTSTR Name);
	BOOL Launch();
	void LaunchAddJSL(LPCTSTR JSL);
	BOOL LaunchRemoveWeight(LPCTSTR Name);
	BOOL LaunchRemoveFreq(LPCTSTR Name);
	BOOL LaunchRemoveBlock(LPCTSTR Name);
	BOOL LaunchRemoveX(LPCTSTR Name);
	BOOL LaunchRemoveY(LPCTSTR Name);
	BOOL LaunchRemoveBy(LPCTSTR Name);
	BOOL MatchingColumn(LPCTSTR columnName);
	BOOL NomAxisBooleanOption(long handle, long action, BOOL flag);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoConting wrapper class

class IAutoConting : public COleDispatchDriver
{
public:
	IAutoConting() {}		// Calls COleDispatchDriver default constructor
	IAutoConting(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoConting(const IAutoConting& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	void MosaicPlot(BOOL flag);
	LPDISPATCH Crosstabs(BOOL flag);
	void Tests(BOOL flag);
	void Correspondence(BOOL flag);
	BOOL Cochran(LPCTSTR columnName);
	BOOL LaunchAddX(LPCTSTR Name);
	BOOL LaunchAddY(LPCTSTR Name);
	BOOL LaunchAddWeight(LPCTSTR Name);
	BOOL LaunchAddFreq(LPCTSTR Name);
	BOOL LaunchAddBy(LPCTSTR Name);
	BOOL Launch();
	void LaunchAddJSL(LPCTSTR JSL);
	BOOL LaunchRemoveX(LPCTSTR Name);
	BOOL LaunchRemoveY(LPCTSTR Name);
	BOOL LaunchRemoveWeight(LPCTSTR Name);
	BOOL LaunchRemoveFreq(LPCTSTR Name);
	BOOL LaunchRemoveBy(LPCTSTR Name);
	BOOL NomAxisBooleanOption(long handle, long action, BOOL flag);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoCrosstabs wrapper class

class IAutoCrosstabs : public COleDispatchDriver
{
public:
	IAutoCrosstabs() {}		// Calls COleDispatchDriver default constructor
	IAutoCrosstabs(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoCrosstabs(const IAutoCrosstabs& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:

// Operations
public:
	void Count(BOOL flag);
	void Total(BOOL flag);
	void Row(BOOL flag);
	void Col(BOOL flag);
	void Expected(BOOL flag);
	void Deviation(BOOL flag);
	void CellChiSquare(BOOL flag);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoDistrib wrapper class

class IAutoDistrib : public COleDispatchDriver
{
public:
	IAutoDistrib() {}		// Calls COleDispatchDriver default constructor
	IAutoDistrib(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoDistrib(const IAutoDistrib& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	void OutlierBoxPlot(BOOL flag);
	void QuantileBoxPlot(BOOL flag);
	void StemAndLeaf(BOOL flag);
	void Histogram(BOOL flag);
	void Save(long action);
	void HorizontalLayout(BOOL flag);
	void UniformScaling(BOOL flag);
	void quantiles(BOOL flag);
	void Moments(BOOL flag);
	void MoreMoments(BOOL flag);
	void CapabilityAnalysis(double LowerLimit, double UpperLimit, double Target, double Sigma);
	void TestMean(double meanToTest, double Sigma, BOOL Wilcoxon);
	LPDISPATCH FitDistribution(long type);
	void SmoothCurve(BOOL flag);
	void ErrorBars(BOOL flag);
	void CountAxis(BOOL flag);
	void ProbAxis(BOOL flag);
	void DensityAxis(BOOL flag);
	void CDFPlot(BOOL flag);
	BOOL LaunchAddColumn(LPCTSTR Name);
	BOOL LaunchAddFreq(LPCTSTR Name);
	BOOL LaunchAddWeight(LPCTSTR Name);
	BOOL LaunchAddBy(LPCTSTR Name);
	void LaunchAddJSL(LPCTSTR JSL);
	BOOL LaunchRemoveColumn(LPCTSTR Name);
	BOOL LaunchRemoveWeight(LPCTSTR Name);
	BOOL LaunchRemoveFreq(LPCTSTR Name);
	BOOL LaunchRemoveBy(LPCTSTR Name);
	BOOL Launch();
	void TestStdDev(double stdDeviation);
	void ConfidenceInterval(double interval);
	void NormalQuantilePlot(BOOL flag);
	void MosaicPlot(BOOL flag);
	void Frequencies(BOOL flag);
	void ToleranceInterval(double alpha, double proportion);
	BOOL NomAxisBooleanOption(long handle, long action, BOOL flag);
	void TestMeanWithOptions(double meanToTest, double Sigma, BOOL Wilcoxon, BOOL pValue, BOOL Power);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoDistribFit wrapper class

class IAutoDistribFit : public COleDispatchDriver
{
public:
	IAutoDistribFit() {}		// Calls COleDispatchDriver default constructor
	IAutoDistribFit(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoDistribFit(const IAutoDistribFit& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:

// Operations
public:
	void QuantilePlot(BOOL flag);
	void DensityCurve(BOOL flag);
	void GoodnessOfFit(BOOL flag);
	void SaveDensityFormula();
	void SaveFittedQuantiles();
	void quantiles(double UpperLimit, double LowerLimit, double Target);
	void RemoveFit();
	BOOL QuantilePlotAction(long action, BOOL flag);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoMultiv wrapper class

class IAutoMultiv : public COleDispatchDriver
{
public:
	IAutoMultiv() {}		// Calls COleDispatchDriver default constructor
	IAutoMultiv(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoMultiv(const IAutoMultiv& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	void InverseCorr(BOOL flag);
	void CorrelationsM(BOOL flag);
	void PartialCorr(BOOL flag);
	void PairwiseCorr(BOOL flag);
	LPDISPATCH ScatterPlot(BOOL flag);
	LPDISPATCH OutlierAnalysis(BOOL flag);
	void CronbachsAlpha(BOOL flag);
	void StandardizedAlpha(BOOL flag);
	void KendallsTau(BOOL flag);
	void SpearmansRho(BOOL flag);
	void HoeffdingsD(BOOL flag);
	LPDISPATCH PrincipalOnCorrelations();
	LPDISPATCH PrincipalOnCovariances();
	LPDISPATCH PrincipalUncentered();
	void CovarianceMatrix(BOOL flag);
	BOOL LaunchAddColumn(LPCTSTR Name);
	BOOL LaunchAddWeight(LPCTSTR Name);
	BOOL LaunchAddFreq(LPCTSTR Name);
	BOOL LaunchAddBy(LPCTSTR Name);
	BOOL Launch();
	BOOL LaunchRemoveColumn(LPCTSTR Name);
	BOOL LaunchRemoveWeight(LPCTSTR Name);
	BOOL LaunchRemoveFreq(LPCTSTR Name);
	BOOL LaunchRemoveBy(LPCTSTR Name);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoScatter wrapper class

class IAutoScatter : public COleDispatchDriver
{
public:
	IAutoScatter() {}		// Calls COleDispatchDriver default constructor
	IAutoScatter(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoScatter(const IAutoScatter& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:

// Operations
public:
	void DensityEllipses(BOOL flag);
	void EllipseColor(long jmpColor);
	void EllipseAlpha(double alpha);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoOutlier wrapper class

class IAutoOutlier : public COleDispatchDriver
{
public:
	IAutoOutlier() {}		// Calls COleDispatchDriver default constructor
	IAutoOutlier(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoOutlier(const IAutoOutlier& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:

// Operations
public:
	void MahalanobisDistances(BOOL flag);
	void JackknifeDistances(BOOL flag);
	void SaveMahal();
	void SaveJackknife();
};
/////////////////////////////////////////////////////////////////////////////
// IAutoPrincipal wrapper class

class IAutoPrincipal : public COleDispatchDriver
{
public:
	IAutoPrincipal() {}		// Calls COleDispatchDriver default constructor
	IAutoPrincipal(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoPrincipal(const IAutoPrincipal& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:

// Operations
public:
	void FactorRotation(long factor);
	void Spin(BOOL flag);
	void SavePrincipal(long factor);
	void SaveRotated();
};
/////////////////////////////////////////////////////////////////////////////
// IAutoControl wrapper class

class IAutoControl : public COleDispatchDriver
{
public:
	IAutoControl() {}		// Calls COleDispatchDriver default constructor
	IAutoControl(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoControl(const IAutoControl& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL LaunchAddSampleLabel(LPCTSTR Name);
	BOOL LaunchAddSampleUnitSize(LPCTSTR Name);
	BOOL LaunchAddProcess(LPCTSTR Name);
	BOOL LaunchAddBy(LPCTSTR Name);
	BOOL LaunchRemoveProcess(LPCTSTR Name);
	BOOL LaunchRemoveSampleUnitSize(LPCTSTR Name);
	BOOL LaunchRemoveSampleLabel(LPCTSTR Name);
	BOOL LaunchRemoveBy(LPCTSTR Name);
	BOOL Launch();
	void LaunchAddJSL(LPCTSTR JSL);
	void LaunchSetChartType(long type);
	void LaunchSetVariableChartParms(BOOL XBar, BOOL R, BOOL S);
	void LaunchSetIRChartParms(BOOL IndMeasurement, BOOL MovingRange, short RangeSpan);
	void LaunchSetIRSummarizeParms(BOOL PreSummarize, BOOL Mean, BOOL StdDev);
	void LaunchSetConstantSampleSize(BOOL flag, short sampleSize);
	void LaunchSetKSigmaAlphaH(BOOL KSigma, BOOL alpha, BOOL H, double value, double beta);
	void LaunchSetEWMAWeight(double weight);
	void LaunchSetUWMAMovingAvg(double MovingAvgSpan);
	void LaunchSetCusumOptions(BOOL twoSided, BOOL dataUnits);
	BOOL LaunchSetVariableStats(double Sigma, double MeanXBar, double MeanR, double MeanS);
	BOOL LaunchSetIRStats(double Sigma, double MeanMeasure, double MeanRange);
	BOOL LaunchSetPStats(double PMean);
	BOOL LaunchSetNPStats(double NPMean);
	BOOL LaunchSetCStats(double CMean);
	BOOL LaunchSetUStats(double UMean);
	BOOL LaunchSetUWMAStats(double Sigma, double Mean);
	BOOL LaunchSetEWMAStats(double Sigma, double Mean);
	BOOL LaunchSetCusumStats(double Target, double delta, double shift, double Sigma, double headstart);
	BOOL LaunchSetIRPreSummarizeStats(double sigmaM, double Mean, double meanMR, double sigmaStd, double meanStd, double meanStdMR);
	void BoxChart(BOOL flag);
	void Needles(BOOL flag);
	void ConnectPoints(BOOL flag);
	void ShowPoints(BOOL flag);
	void ShowCenter(BOOL flag);
	void ControlLimits(BOOL flag);
	void ShowZones(BOOL flag);
	LPDISPATCH SaveLimits(BOOL flag);
	void ShowLineLegend(BOOL flag);
	void ShowCusumARL(BOOL flag);
	void ConnectThroughMissing(BOOL flag);
	void TestsAll(BOOL flag);
	BOOL Test(short TestNumber, BOOL flag);
	BOOL OCCurve();
	void ConnectColor(long color);
	void CenterColor(long color);
	void LimitsColor(long color);
	long SetAlarm(long alarmType);
	long SetCustomAlarmText(long Speak, LPCTSTR text);
	void LaunchSpecifyCapability(double LSL, double USL, double Target);
	BOOL SetActiveChart(short chartNumber);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoOverlay wrapper class

class IAutoOverlay : public COleDispatchDriver
{
public:
	IAutoOverlay() {}		// Calls COleDispatchDriver default constructor
	IAutoOverlay(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoOverlay(const IAutoOverlay& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL LaunchAddX(LPCTSTR Name);
	BOOL LaunchAddY(LPCTSTR Name);
	BOOL LaunchAddGrouping(LPCTSTR Name);
	BOOL LaunchAddBy(LPCTSTR Name);
	BOOL Launch();
	BOOL LaunchRemoveX(LPCTSTR Name);
	BOOL LaunchRemoveY(LPCTSTR Name);
	BOOL LaunchRemoveGrouping(LPCTSTR Name);
	BOOL LaunchRemoveBy(LPCTSTR Name);
	void AddJSL(LPCTSTR JSL);
	void Overlay(BOOL flag);
	void Range(BOOL flag);
	void YNeedle(BOOL flag);
	void YShowPoints(BOOL flag);
	void YConnectPoints(BOOL flag);
	void YStep(BOOL flag);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoLogistic wrapper class

class IAutoLogistic : public COleDispatchDriver
{
public:
	IAutoLogistic() {}		// Calls COleDispatchDriver default constructor
	IAutoLogistic(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoLogistic(const IAutoLogistic& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL LaunchAddX(LPCTSTR Name);
	BOOL LaunchAddY(LPCTSTR Name);
	BOOL LaunchAddWeight(LPCTSTR Name);
	BOOL LaunchAddFreq(LPCTSTR Name);
	BOOL LaunchAddBy(LPCTSTR Name);
	BOOL Launch();
	void LaunchAddJSL();
	BOOL LaunchRemoveX(LPCTSTR Name);
	BOOL LaunchRemoveY(LPCTSTR Name);
	BOOL LaunchRemoveWeight(LPCTSTR Name);
	BOOL LaunchRemoveFreq(LPCTSTR Name);
	BOOL LaunchRemoveBy(LPCTSTR Name);
	void LogisticPlot(BOOL flag);
	void ROCCurve(BOOL flag);
	void InversePrediction();
	void AddGraphicsSegments(LPCTSTR JSLText);
	BOOL NomAxisBooleanOption(long handle, long action, BOOL flag);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoSurvival wrapper class

class IAutoSurvival : public COleDispatchDriver
{
public:
	IAutoSurvival() {}		// Calls COleDispatchDriver default constructor
	IAutoSurvival(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoSurvival(const IAutoSurvival& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL LaunchAddGroup(LPCTSTR Name);
	BOOL LaunchAddTime(LPCTSTR Name);
	BOOL LaunchAddCensor(LPCTSTR Name);
	BOOL LaunchAddFreq(LPCTSTR Name);
	BOOL LaunchAddBy(LPCTSTR Name);
	BOOL Launch();
	BOOL LaunchRemoveGroup(LPCTSTR Name);
	BOOL LaunchRemoveTime(LPCTSTR Name);
	BOOL LaunchRemoveCensor(LPCTSTR Name);
	BOOL LaunchRemoveFreq(LPCTSTR Name);
	BOOL LaunchRemoveBy(LPCTSTR Name);
	void LaunchAddJSL(LPCTSTR JSL);
	void ShowPoints(BOOL flag);
	void ShowCombined(BOOL flag);
	void ShowConfidInterval(BOOL flag);
	void ReverseYAxis(BOOL flag);
	void SurvivalPlot(BOOL flag);
	void ExponentialPlot(BOOL flag);
	void WeibullPlot(BOOL flag);
	void LognormalPlot(BOOL flag);
	BOOL CompetingCauses(LPCTSTR columnName);
	void ExponentialEst(BOOL flag);
	void WeibullEst(BOOL flag);
	void LognormalEst(BOOL flag);
	LPDISPATCH SaveEstimates();
	void FailurePlot(BOOL flag);
	void FittedDistributionPlots(BOOL flag);
	void MidstepQuantilePoints(BOOL flag);
	void CompetingCauseAction(long action, BOOL flag);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoMatchedPairs wrapper class

class IAutoMatchedPairs : public COleDispatchDriver
{
public:
	IAutoMatchedPairs() {}		// Calls COleDispatchDriver default constructor
	IAutoMatchedPairs(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoMatchedPairs(const IAutoMatchedPairs& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL LaunchAddGrouping(LPCTSTR Name);
	BOOL LaunchAddPairedColumns(LPCTSTR Name);
	BOOL LaunchAddWeight(LPCTSTR Name);
	BOOL LaunchAddFreq(LPCTSTR Name);
	BOOL LaunchAddBy(LPCTSTR Name);
	BOOL Launch();
	void LaunchAddJSL(LPCTSTR JSL);
	BOOL LaunchRemoveGrouping(LPCTSTR Name);
	BOOL LaunchRemovePairedColumns(LPCTSTR Name);
	BOOL LaunchRemoveWeight(LPCTSTR Name);
	BOOL LaunchRemoveFreq(LPCTSTR Name);
	BOOL LaunchRemoveBy(LPCTSTR Name);
	void PlotDifByMean(BOOL flag);
	void PlotDifByRow(BOOL flag);
	void ReferenceFrame(BOOL flag);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoSpin wrapper class

class IAutoSpin : public COleDispatchDriver
{
public:
	IAutoSpin() {}		// Calls COleDispatchDriver default constructor
	IAutoSpin(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoSpin(const IAutoSpin& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL LaunchAddColumn(LPCTSTR Name);
	BOOL LaunchAddWeight(LPCTSTR Name);
	BOOL LaunchAddFreq(LPCTSTR Name);
	BOOL LaunchAddBy(LPCTSTR Name);
	BOOL Launch();
	BOOL LaunchRemoveColumn(LPCTSTR Name);
	BOOL LaunchRemoveWeight(LPCTSTR Name);
	BOOL LaunchRemoveFreq(LPCTSTR Name);
	BOOL LaunchRemoveBy(LPCTSTR Name);
	void LaunchAddJSL(LPCTSTR JSL);
	void PrincipalComponents(BOOL flag);
	void StdPrincipalComponents(BOOL flag);
	void RotatedComponents(short number);
	void BiplotRays(BOOL flag);
	void SavePrincipalComponents();
	void SaveRotatedComponents();
	void Spin(short pitch, short yaw, short roll, short numTimes);
	void SpinPitch(short pitch);
	void SpinYaw(short yaw);
	void SpinRoll(short roll);
	void SpinStop();
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoPareto wrapper class

class IAutoPareto : public COleDispatchDriver
{
public:
	IAutoPareto() {}		// Calls COleDispatchDriver default constructor
	IAutoPareto(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoPareto(const IAutoPareto& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL LaunchAddX(LPCTSTR Name);
	BOOL LaunchAddCause(LPCTSTR Name);
	BOOL LaunchAddWeight(LPCTSTR Name);
	BOOL Launch();
	BOOL LaunchAddFreq(LPCTSTR Name);
	BOOL LaunchAddBy(LPCTSTR Name);
	BOOL LaunchRemoveX(LPCTSTR Name);
	BOOL LaunchRemoveCause(LPCTSTR Name);
	BOOL LaunchRemoveFreq(LPCTSTR Name);
	BOOL LaunchRemoveWeight(LPCTSTR Name);
	BOOL LaunchRemoveBy(LPCTSTR Name);
	void LaunchAddJSL(LPCTSTR JSL);
	void PercentScale(BOOL flag);
	void PieChart(BOOL flag);
	void HorizontalLayout(BOOL flag);
	void CumPercentCurve(BOOL flag);
	void CumPercentAxis(BOOL flag);
	void CumPercentPoints(BOOL flag);
	void CategoryLegend(BOOL flag);
	void NLegend(BOOL flag);
	void LabelCumPoints(BOOL flag);
	void UngroupPlots(BOOL flag);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoTimeSeries wrapper class

class IAutoTimeSeries : public COleDispatchDriver
{
public:
	IAutoTimeSeries() {}		// Calls COleDispatchDriver default constructor
	IAutoTimeSeries(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoTimeSeries(const IAutoTimeSeries& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL LaunchAddXTime(LPCTSTR Name);
	BOOL LaunchAddYSeries(LPCTSTR Name);
	BOOL LaunchAddBy(LPCTSTR Name);
	BOOL Launch();
	BOOL LaunchRemoveXTime(LPCTSTR Name);
	BOOL LaunchRemoveYSeries(LPCTSTR Name);
	BOOL LaunchRemoveBy(LPCTSTR Name);
	void LaunchAddJSL(LPCTSTR JSL);
	void LaunchAddNumAutoCorrLags(long n);
	void LaunchAddNumFrequencyPer(long n);
	void Autocorrelation(BOOL flag);
	void PartialAutocorr(BOOL flag);
	void Variogram(BOOL flag);
	void ARCoefficients(BOOL flag);
	void SpectralDensity(BOOL flag);
	LPDISPATCH SaveSpectralDensity();
	void TimeSeriesGraph(BOOL flag);
	void ShowPoints(BOOL flag);
	void ConnectingLines(BOOL flag);
	void MeanLine(BOOL flag);
	void ARIMA(double p, double d, double q, double confidInterval, BOOL intercept, BOOL constrain);
	BOOL SmoothingModel(long model, long constraints);
	void SeasonalARIMA(double p, double d, double q, double SeasonalP, double SeasonalD, double SeasonalQ, double Periods, double confidInterval, BOOL intercept, BOOL constrain);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoTernary wrapper class

class IAutoTernary : public COleDispatchDriver
{
public:
	IAutoTernary() {}		// Calls COleDispatchDriver default constructor
	IAutoTernary(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoTernary(const IAutoTernary& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL LaunchAddCol(LPCTSTR Name);
	BOOL LaunchAddBy(LPCTSTR Name);
	BOOL Launch();
	BOOL LaunchRemoveCol(LPCTSTR Name);
	BOOL LaunchRemoveBy(LPCTSTR Name);
	void LaunchAddJSL(LPCTSTR JSL);
	void RefLines(long flag);
	void RefLabels(long flag);
	BOOL LaunchAddFormulaCol(LPCTSTR Name);
	BOOL LaunchRemoveFormulaCol(LPCTSTR Name);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoProfiler wrapper class

class IAutoProfiler : public COleDispatchDriver
{
public:
	IAutoProfiler() {}		// Calls COleDispatchDriver default constructor
	IAutoProfiler(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoProfiler(const IAutoProfiler& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL LaunchAddY(LPCTSTR Name);
	BOOL Launch();
	BOOL LaunchRemoveY(LPCTSTR Name);
	void LaunchAddJSL(LPCTSTR JSL);
	void ConfidenceIntervals(BOOL flag);
	void Desirability(BOOL flag);
	void MostDesirable();
	void SaveDesirability();
	void OutputGridTable();
	void InteractionProfiler(BOOL flag);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoContourProfiler wrapper class

class IAutoContourProfiler : public COleDispatchDriver
{
public:
	IAutoContourProfiler() {}		// Calls COleDispatchDriver default constructor
	IAutoContourProfiler(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoContourProfiler(const IAutoContourProfiler& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL LaunchAddY(LPCTSTR Name);
	BOOL Launch();
	BOOL LaunchRemoveY(LPCTSTR Name);
	void LaunchAddJSL(LPCTSTR JSL);
	void SurfacePlot(BOOL flag);
	void ContourGrid(double low, double high, double increment);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoContour wrapper class

class IAutoContour : public COleDispatchDriver
{
public:
	IAutoContour() {}		// Calls COleDispatchDriver default constructor
	IAutoContour(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoContour(const IAutoContour& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL LaunchAddX(LPCTSTR Name);
	BOOL LaunchAddY(LPCTSTR Name);
	BOOL LaunchAddBy(LPCTSTR Name);
	BOOL Launch();
	BOOL LaunchRemoveX(LPCTSTR Name);
	BOOL LaunchRemoveY(LPCTSTR Name);
	BOOL LaunchRemoveBy(LPCTSTR Name);
	void LaunchAddJSL(LPCTSTR JSL);
	void FillAreas(BOOL flag);
	void ShowDataPoints(BOOL flag);
	void ShowContours(BOOL flag);
	void ShowBoundary(BOOL flag);
	void ReverseColors(BOOL flag);
	void LabelContours(BOOL flag);
	LPDISPATCH SaveContours();
	LPDISPATCH SaveTriangulation();
	LPDISPATCH GenerateGrid(long horizontal, long vertical);
	void SpecifyContours(double Minimum, double Maximum, double n, BOOL nIsIncrement);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoRecur wrapper class

class IAutoRecur : public COleDispatchDriver
{
public:
	IAutoRecur() {}		// Calls COleDispatchDriver default constructor
	IAutoRecur(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoRecur(const IAutoRecur& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL LaunchAddGroup(LPCTSTR Name);
	BOOL LaunchAddAge(LPCTSTR Name);
	BOOL LaunchAddCost(LPCTSTR Name);
	BOOL LaunchAddLabel(LPCTSTR Name);
	BOOL LaunchAddBy(LPCTSTR Name);
	BOOL Launch();
	BOOL LaunchRemoveGroup(LPCTSTR Name);
	BOOL LaunchRemoveAge(LPCTSTR Name);
	BOOL LaunchRemoveCost(LPCTSTR Name);
	BOOL LaunchRemoveLabel(LPCTSTR Name);
	BOOL LaunchRemoveBy(LPCTSTR Name);
	void LaunchAddJSL(LPCTSTR JSL);
	void MCFPlot(BOOL flag);
	void MCFConfidLimits(BOOL flag);
	void EventPlot(BOOL flag);
	void PlotMCFDifferences(BOOL flag);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoVariChart wrapper class

class IAutoVariChart : public COleDispatchDriver
{
public:
	IAutoVariChart() {}		// Calls COleDispatchDriver default constructor
	IAutoVariChart(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoVariChart(const IAutoVariChart& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL LaunchAddX(LPCTSTR Name);
	BOOL LaunchAddY(LPCTSTR Name);
	BOOL LaunchAddBy(LPCTSTR Name);
	BOOL Launch();
	BOOL LaunchRemoveX(LPCTSTR Name);
	BOOL LaunchRemoveY(LPCTSTR Name);
	BOOL LaunchRemoveBy(LPCTSTR Name);
	void LaunchAddJSL(LPCTSTR JSL);
	void ConnectCellMeans(BOOL flag);
	void ShowRangeBars(BOOL flag);
	void ShowCellMeans(BOOL flag);
	void ShowPoints(BOOL flag);
	void ShowGroupMeans(BOOL flag);
	void ShowStdDevChart(BOOL flag);
	BOOL VarianceComponents(long type);
	void ShowVariabilityChart(BOOL flag);
	void DiscriminationRatio(BOOL flag);
	void GageRandR(double K, double Tolerance);
	void ShowGrandMean(BOOL flag);
	BOOL NomAxisBooleanOption(long handle, long action, BOOL flag);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoChart wrapper class

class IAutoChart : public COleDispatchDriver
{
public:
	IAutoChart() {}		// Calls COleDispatchDriver default constructor
	IAutoChart(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoChart(const IAutoChart& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL LaunchAddX(LPCTSTR Name);
	BOOL LaunchAddY(LPCTSTR Name, long stat);
	BOOL LaunchAddWeight(LPCTSTR Name);
	BOOL Launch();
	BOOL LaunchAddFreq(LPCTSTR Name);
	BOOL LaunchAddGroup(LPCTSTR Name);
	BOOL LaunchAddBy(LPCTSTR Name);
	BOOL LaunchRemoveX(LPCTSTR Name);
	BOOL LaunchRemoveY(LPCTSTR Name);
	BOOL LaunchRemoveFreq(LPCTSTR Name);
	BOOL LaunchRemoveWeight(LPCTSTR Name);
	BOOL LaunchRemoveGroup(LPCTSTR Name);
	BOOL LaunchRemoveBy(LPCTSTR Name);
	void LaunchAddJSL(LPCTSTR JSL);
	void Overlay(BOOL flag);
	void orientation(long which);
	void SpecifyType(long chartType);
	void ConnectPoints(BOOL flag);
	void ShowPoints(BOOL flag);
	void SeparateAxes(BOOL flag);
	void OverlayColor(long color);
	BOOL SpecifyQuantileValue(double val);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoFitModel wrapper class

class IAutoFitModel : public COleDispatchDriver
{
public:
	IAutoFitModel() {}		// Calls COleDispatchDriver default constructor
	IAutoFitModel(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoFitModel(const IAutoFitModel& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:

// Operations
public:
	BOOL LaunchAddY(LPCTSTR Name);
	BOOL LaunchAddWeight(LPCTSTR Name);
	BOOL LaunchAddFreq(LPCTSTR Name);
	BOOL LaunchAddBy(LPCTSTR Name);
	LPDISPATCH Launch();
	BOOL LaunchRemoveY(LPCTSTR Name);
	BOOL LaunchRemoveWeight(LPCTSTR Name);
	BOOL LaunchRemoveFreq(LPCTSTR Name);
	BOOL LaunchRemoveBy(LPCTSTR Name);
	BOOL LaunchAddToEffectList(LPCTSTR Name);
	BOOL LaunchRemoveFromEffectList(LPCTSTR Name);
	BOOL LaunchAddXEffect();
	BOOL LaunchAddCrossEffect();
	BOOL LaunchAddNestEffect();
	BOOL LaunchAddMacroEffect(long type);
	BOOL LaunchSpecifyMacroDegree(short degree);
	BOOL LaunchSpecifyPersonality(long personality);
	BOOL LaunchSpecifyEmphasis(long emphasis);
	BOOL LaunchSpecifyDistribution(long distrib);
	CString LaunchGetEffectName(short effectNumber);
	short LaunchGetNumberOfEffects();
	long LaunchRemoveSelectedEffects();
	long LaunchSelectEffect(short effectNumber, BOOL OnOff);
	long LaunchSpecifyAttributesForSelectedEffects(long attribNumber);
	void LaunchSpecifyIntercept(BOOL InterceptOn);
	BOOL LaunchAddJSL(LPCTSTR JSL);
	LPDISPATCH UseByFit(LPCTSTR Name);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoPLS wrapper class

class IAutoPLS : public COleDispatchDriver
{
public:
	IAutoPLS() {}		// Calls COleDispatchDriver default constructor
	IAutoPLS(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoPLS(const IAutoPLS& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL LaunchAddX(LPCTSTR Name);
	BOOL LaunchAddY(LPCTSTR Name);
	BOOL LaunchAddWeight(LPCTSTR Name);
	BOOL LaunchAddFreq(LPCTSTR Name);
	BOOL LaunchAddBy(LPCTSTR Name);
	BOOL Launch();
	void LaunchAddJSL(LPCTSTR JSL);
	BOOL LaunchRemoveX(LPCTSTR Name);
	BOOL LaunchRemoveY(LPCTSTR Name);
	BOOL LaunchRemoveWeight(LPCTSTR Name);
	BOOL LaunchRemoveFreq(LPCTSTR Name);
	BOOL LaunchRemoveBy(LPCTSTR Name);
	BOOL ShowPoints(BOOL flag);
	BOOL ConfidenceLines(BOOL flag);
	BOOL SaveOutputs(BOOL flag);
	void SavePredictionFormula();
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoDiagram wrapper class

class IAutoDiagram : public COleDispatchDriver
{
public:
	IAutoDiagram() {}		// Calls COleDispatchDriver default constructor
	IAutoDiagram(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoDiagram(const IAutoDiagram& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL LaunchAddX(LPCTSTR Name);
	BOOL LaunchAddY(LPCTSTR Name);
	BOOL LaunchAddBy(LPCTSTR Name);
	BOOL Launch();
	void LaunchAddJSL(LPCTSTR JSL);
	BOOL LaunchRemoveX(LPCTSTR Name);
	BOOL LaunchRemoveY(LPCTSTR Name);
	BOOL LaunchRemoveBy(LPCTSTR Name);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoDiscrim wrapper class

class IAutoDiscrim : public COleDispatchDriver
{
public:
	IAutoDiscrim() {}		// Calls COleDispatchDriver default constructor
	IAutoDiscrim(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoDiscrim(const IAutoDiscrim& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL LaunchAddX(LPCTSTR Name);
	BOOL LaunchAddY(LPCTSTR Name);
	BOOL LaunchAddBy(LPCTSTR Name);
	BOOL Launch();
	void LaunchAddJSL(LPCTSTR JSL);
	BOOL LaunchRemoveX(LPCTSTR Name);
	BOOL LaunchRemoveY(LPCTSTR Name);
	BOOL LaunchRemoveBy(LPCTSTR Name);
	BOOL ScoreOptions(long option, BOOL flag);
	BOOL CanonicalOptions(long option, BOOL flag);
	void ShowCanonicalPlot(BOOL flag);
	void ScoreData(BOOL flag);
	void ShowWithinCovariances(BOOL flag);
	void ShowGroupMeans(BOOL flag);
	void SaveDiscrimMatrices();
	void ScoreSelectUncertainRows(double value);
	void StepwiseSetup();
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoNeural wrapper class

class IAutoNeural : public COleDispatchDriver
{
public:
	IAutoNeural() {}		// Calls COleDispatchDriver default constructor
	IAutoNeural(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoNeural(const IAutoNeural& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL LaunchAddX(LPCTSTR Name);
	BOOL LaunchAddY(LPCTSTR Name);
	BOOL LaunchAddWeight(LPCTSTR Name);
	BOOL LaunchAddFreq(LPCTSTR Name);
	BOOL LaunchAddBy(LPCTSTR Name);
	BOOL Launch();
	void LaunchAddJSL(LPCTSTR JSL);
	BOOL LaunchRemoveX(LPCTSTR Name);
	BOOL LaunchRemoveY(LPCTSTR Name);
	BOOL LaunchRemoveWeight(LPCTSTR Name);
	BOOL LaunchRemoveFreq(LPCTSTR Name);
	BOOL LaunchRemoveBy(LPCTSTR Name);
	BOOL SpecifyHiddenNodes(double value);
	BOOL SpecifyOverfitPenalty(double value);
	BOOL SpecifyNumberOfTours(double value);
	BOOL SpecifyMaxIterations(double value);
	BOOL SpecifyConvergeCriterion(double value);
	BOOL ControlPanelOptions(long option, BOOL flag);
	BOOL Go();
	BOOL Profiler(BOOL flag);
	BOOL Diagram(BOOL flag);
	void SaveHidden();
	void SavePredicted();
	void SaveFormulas();
	void SaveProfileFormulas();
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoTextImport wrapper class

class IAutoTextImport : public COleDispatchDriver
{
public:
	IAutoTextImport() {}		// Calls COleDispatchDriver default constructor
	IAutoTextImport(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoTextImport(const IAutoTextImport& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:

// Operations
public:
	void SetEndOfFieldOptions(short options);
	void SetEndOfLineOptions(short options);
	void FirstLineIsData(BOOL flag);
	void StripQuotes(BOOL flag);
	BOOL SetColumnType(long columnNumber, long columnType);
	LPDISPATCH OpenFile();
};
/////////////////////////////////////////////////////////////////////////////
// IAutoDB wrapper class

class IAutoDB : public COleDispatchDriver
{
public:
	IAutoDB() {}		// Calls COleDispatchDriver default constructor
	IAutoDB(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoDB(const IAutoDB& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:

// Operations
public:
	BOOL Disconnect();
	BOOL Connect(LPCTSTR szConnectString);
	LPDISPATCH ExecuteSQLSelect(LPCTSTR szSQL);
	BOOL ExecuteSQL(LPCTSTR szSQL);
	LPDISPATCH OpenTable(LPCTSTR szTableName);
	BOOL SaveTable(LPDISPATCH pTable, LPCTSTR szTableName);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoDataFeed wrapper class

class IAutoDataFeed : public COleDispatchDriver
{
public:
	IAutoDataFeed() {}		// Calls COleDispatchDriver default constructor
	IAutoDataFeed(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoDataFeed(const IAutoDataFeed& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:

// Operations
public:
	BOOL Disconnect();
	BOOL Connect(LPCTSTR szCommPort);
	BOOL SetCommParms(LPCTSTR szCommPort, long baudrate, long parity, short databits, short stopbits, long flow);
	BOOL Close();
	CString GetLine();
};
/////////////////////////////////////////////////////////////////////////////
// IAutoFitEffect wrapper class

class IAutoFitEffect : public COleDispatchDriver
{
public:
	IAutoFitEffect() {}		// Calls COleDispatchDriver default constructor
	IAutoFitEffect(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoFitEffect(const IAutoFitEffect& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:

// Operations
public:
	BOOL LSMeansTable(BOOL flag);
	BOOL LSMeansPlot(BOOL flag);
	BOOL LSMeansStudents(BOOL flag);
	BOOL LSMeansTukey(BOOL flag);
	BOOL TestSlices();
};
/////////////////////////////////////////////////////////////////////////////
// IAutoFitResponse wrapper class

class IAutoFitResponse : public COleDispatchDriver
{
public:
	IAutoFitResponse() {}		// Calls COleDispatchDriver default constructor
	IAutoFitResponse(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoFitResponse(const IAutoFitResponse& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL ExpandedEstimates(BOOL flag);
	BOOL SequentialTests(BOOL flag);
	BOOL ParameterPower(BOOL flag);
	BOOL CorrelationOfEstimates(BOOL flag);
	BOOL ScaledEstimates(BOOL flag);
	BOOL NormalPlot(BOOL flag);
	BOOL ParetoPlot(BOOL flag);
	BOOL InteractionPlots(BOOL flag);
	BOOL BoxCoxY(BOOL flag);
	BOOL RowDiagnostics(long diagType, BOOL flag);
	BOOL SaveColumns(long saveType);
	LPDISPATCH GetEffectAnalysis(LPCTSTR Name);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoFitProfiler wrapper class

class IAutoFitProfiler : public COleDispatchDriver
{
public:
	IAutoFitProfiler() {}		// Calls COleDispatchDriver default constructor
	IAutoFitProfiler(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoFitProfiler(const IAutoFitProfiler& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:

// Operations
public:
	BOOL ConfidenceIntervals(BOOL flag);
	BOOL DesirabilityFunctions(BOOL flag);
	BOOL MaximizeDesirability();
	BOOL ResetYScale(double min, double max);
	void SaveDesirabilities();
	LPDISPATCH OutputGridTable();
	BOOL InteractionProfiler(BOOL flag);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoFitLS wrapper class

class IAutoFitLS : public COleDispatchDriver
{
public:
	IAutoFitLS() {}		// Calls COleDispatchDriver default constructor
	IAutoFitLS(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoFitLS(const IAutoFitLS& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	LPDISPATCH Profiler(BOOL flag);
	BOOL ContourProfiler(BOOL flag);
	BOOL CubePlot(BOOL flag);
	LPDISPATCH GetResponse(LPCTSTR responseName);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoFitLV wrapper class

class IAutoFitLV : public COleDispatchDriver
{
public:
	IAutoFitLV() {}		// Calls COleDispatchDriver default constructor
	IAutoFitLV(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoFitLV(const IAutoFitLV& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL LikelihoodRatio(BOOL flag);
	BOOL ConfidenceInterval(double alphaLevel);
	BOOL MarginalVariances(BOOL flag);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoFitNom wrapper class

class IAutoFitNom : public COleDispatchDriver
{
public:
	IAutoFitNom() {}		// Calls COleDispatchDriver default constructor
	IAutoFitNom(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoFitNom(const IAutoFitNom& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL LikelihoodRatioTests(BOOL flag);
	BOOL ConfidenceIntervals(double alpha);
	BOOL OddsRatios(BOOL flag);
	BOOL InversePrediction();
	BOOL SaveProbFormula();
	BOOL ROCCurve(BOOL flag);
	BOOL Profiler(BOOL flag);
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoFitOrd wrapper class

class IAutoFitOrd : public COleDispatchDriver
{
public:
	IAutoFitOrd() {}		// Calls COleDispatchDriver default constructor
	IAutoFitOrd(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoFitOrd(const IAutoFitOrd& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL LikelihoodRatioTests(BOOL flag);
	BOOL ConfidenceIntervals(double alpha);
	BOOL SaveQuantiles();
	BOOL SaveProbFormula();
	BOOL SaveExpectedValue();
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoFitProp wrapper class

class IAutoFitProp : public COleDispatchDriver
{
public:
	IAutoFitProp() {}		// Calls COleDispatchDriver default constructor
	IAutoFitProp(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoFitProp(const IAutoFitProp& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoFitStep wrapper class

class IAutoFitStep : public COleDispatchDriver
{
public:
	IAutoFitStep() {}		// Calls COleDispatchDriver default constructor
	IAutoFitStep(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoFitStep(const IAutoFitStep& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	short GetNumberOfEffects();
	CString GetEffectName(short effectNumber);
	long LockEffect(short effectNumber, long flag);
	long EnterEffect(short effectNumber, long flag);
	long EnterAll();
	long RemoveAll();
	long SetProbToEnter(double value);
	long SetProbToLeave(double value);
	long SetDirection(long direction);
	long SetRules(long rules);
	long Step();
	long Stop();
	long Go();
	void AllPossibleModels();
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoFitParSurv wrapper class

class IAutoFitParSurv : public COleDispatchDriver
{
public:
	IAutoFitParSurv() {}		// Calls COleDispatchDriver default constructor
	IAutoFitParSurv(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoFitParSurv(const IAutoFitParSurv& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL LikelihoodRatioTests(BOOL flag);
	BOOL ConfidenceIntervals(BOOL flag);
	BOOL CorrelationOfEstimates(BOOL flag);
	BOOL CovarianceOfEstimates(BOOL flag);
	void EstimateSurvivalProb();
	void EstimateTimeQuantile();
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IAutoFitManova wrapper class

class IAutoFitManova : public COleDispatchDriver
{
public:
	IAutoFitManova() {}		// Calls COleDispatchDriver default constructor
	IAutoFitManova(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoFitManova(const IAutoFitManova& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetVisible();
	void SetVisible(BOOL);

// Operations
public:
	BOOL SaveDiscrim();
	BOOL SavePredicted();
	BOOL SaveResiduals();
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
	BOOL PrintPages(short from, short to);
	BOOL CopyToClipboard();
	BOOL SaveJournalAs(LPCTSTR filename);
	BOOL SaveGraphicOutputAs(LPCTSTR filename, long format);
	long GetGraphicItemByName(LPCTSTR Name);
	long GetGraphicItemByType(LPCTSTR boxName, short boxNumber);
	BOOL CopyGraphicItem(long handle);
	BOOL SaveGraphicItem(long handle, LPCTSTR filename, long format);
	BOOL JournalGraphicItem(long handle);
	CString GetTextOfGraphicItem(long handle);
	BOOL OutlineBoxClose(long handle);
	LPDISPATCH TableBoxMakeDataTable(long handle);
	CString NumberColGetItemText(long handle, short itemNumber);
	CString StringColGetItemText(long handle, short itemNumber);
	BOOL SetFrameSize(long handle, long cx, long cy);
	BOOL CloseWindow();
	BOOL AxisBoxRevert(long handle);
	// method 'AxisBoxAddLabel' not emitted because of invalid return type or parameter type
	BOOL AxisBoxRemoveLabel(long handle);
	BOOL AxisBoxBooleanOption(long handle, long option, BOOL flag);
	BOOL AxisBoxNumericOption(long handle, long option, double value);
	BOOL AxisBoxInterval(long handle, long interval);
	BOOL AxisBoxScale(long handle, long scale);
	BOOL AxisBoxFormat(long handle, long format);
	BOOL AxisBoxNumberDecimals(long handle, short numberDecimals);
	BOOL AxisBoxAddRefLine(long handle, double where, long style, long color);
	BOOL UseByOutput(LPCTSTR ByTitle);
	BOOL ScriptAction(long action);
	BOOL OutlineBoxSetTitle(long handle, LPCTSTR title);
	LPDISPATCH CreateJournal();
	BOOL JournalOutput();
	BOOL FrameBoxSetMarkerSize(long handle, long size);
	BOOL FrameBoxSetBackColor(long handle, long color);
	BOOL FrameBoxAddGraphicsScript(long handle, LPCTSTR script);
	BOOL SetPrintOrientation(long orientation);
};
/////////////////////////////////////////////////////////////////////////////
// IJMPAnalysisView wrapper class

class IJMPAnalysisView : public COleDispatchDriver
{
public:
	IJMPAnalysisView() {}		// Calls COleDispatchDriver default constructor
	IJMPAnalysisView(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IJMPAnalysisView(const IJMPAnalysisView& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:

// Operations
public:
};
/////////////////////////////////////////////////////////////////////////////
// IAutoAnalysis wrapper class

class IAutoAnalysis : public COleDispatchDriver
{
public:
	IAutoAnalysis() {}		// Calls COleDispatchDriver default constructor
	IAutoAnalysis(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IAutoAnalysis(const IAutoAnalysis& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:

// Operations
public:
	BOOL SetWindowSize(short cx, short cy);
	BOOL SetWindowPos(short x, short y);
	BOOL PrintReport();
};

#endif
