//==========================================================================
// JMPImportML.cpp
//
// Institution: Department of Mathematics
// 			    University of North Carolina
// Date: 09-30-2010
// Copyright: None.
//
// JMPImport is a sample Windows program which provides a function 
// (named "JMPImport") you can call from within a Mathematica notebook 
// to import a JMP data table.  JMPImport uses OLE Automation to 
// to open the JMP data table and MathLink to communicate with Mathematica.
//
// JMPImport requires JMP.exe to be installed on your PC.
//
// To use, execute the following commands from within your Mathematica notebook:
//
//		mlink = Install["<path to JMPImport.exe goes here>"]
//		jmpdata= JMPImport["<path to JMP Data Table or SAS Data Set goes here>"]
//		Uninstall[mlink]
//
// See the "JMPImport Example.nb" sample notebook for more examples.
//
// This source code is not copyrighted.  You are free to use, copy,
// and/or modify this source code however you like.
// Note that this source code is provided "as is" with no warranties
// of any kind implied whatsoever.
//
// The files JMP.cpp and JMP.h used in this project are provided by
// SAS Institute as part of the "AutoClient" automation sample for 
// Visual C++, which is included with JMP.
// For a typical JMP installation, these files can be found at:
// <JMP Installation Directory>\Support Files English\Automation Samples\Visual C++ Sample\AutoClient
//
// No copyrights are violated by including the files JMP.cpp and JMP.h in
// your Visual Studio project.
//
// For instructions on how to create a Visual Studio project in order
// to build JMPImport.exe, consult the file: JMPImport ReadMe.txt
//
//==========================================================================
// JMP(c) and SAS(c) are products of SAS Institute, Inc.
//==========================================================================
#include "stdafx.h"
#include "JMPImportML.h"

//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//		Interface between JMPImport and MathLink
//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#ifdef __cplusplus
 extern "C" {
#endif 

extern void jmpImport( const char * szPath );

#ifdef __cplusplus
 }
#endif

#ifdef __cplusplus
 extern "C" {
#endif

static void importJMPDataTabletoMathematica( const char *szPath );


//This routine is invoked when the user executes the JMPImport[s] command in his/her Mathematica notebook.
void  jmpImport( const char * szPath ) {
    importJMPDataTabletoMathematica( szPath );
}

#ifdef __cplusplus
 }
#endif


#if WINDOWS_MATHLINK

#if __BORLANDC__
#pragma argsused
#endif


//Note: When we are launched by Mathematica, this WinMain will be executed.
//Do NOT place this initialization code in our InitInstance() routine.
//Note that we have customized this version of WinMain to handle initializing
//and uninitializing OLE.
int PASCAL WinMain( HINSTANCE hinstCurrent, HINSTANCE hinstPrevious, LPSTR lpszCmdLine, int nCmdShow)
{
	char  buff[512];
	char FAR * buff_start = buff;
	char FAR * argv[32];
	char FAR * FAR * argv_end = argv + 32;
    int         result_MLMain;

	hinstPrevious = hinstPrevious; /* suppress warning */

	if( !MLInitializeIcon( hinstCurrent, nCmdShow)) return 1;
	MLScanString( argv, &argv_end, &lpszCmdLine, &buff_start);

    if ( !initializeOLE() ) return 1;

    result_MLMain = MLMain( (int)(argv_end - argv), argv);

#if (0) //experiment to launch SAS
	COleDispatchDriver sasDispDriver;
	COleException error;
	if ( !sasDispDriver.CreateDispatch("SAS.Application", &error) ) {
		UINT	nMaxError = 512;
		char	szError[512];
		error.GetErrorMessage( szError, nMaxError );
		AfxMessageBox( szError, MB_OK );
	}

	if ( sasDispDriver.m_lpDispatch == NULL ) {
		AfxMessageBox( "sasDispDriver.m_lpDispatch == NULL", MB_OK );
	}
	if ( sasDispDriver.m_lpDispatch != NULL ) {
		//need to tell SAS to quit

		sasDispDriver.ReleaseDispatch();
	}
#endif
    //AfxMessageBox("MLMain returned");

    unInitializeOLE();

	return result_MLMain;
}

#else

int main(int argc, char* argv[])
{
	return MLMain(argc, argv);
}

#endif



//Use JMP to import the file specified by szPath into Mathematica.
//This is accomplished by connecting to JMP, instructing JMP to open
//the file as a JMP data table, and then sending the data in the JMP
//data table to Mathematica via stdlink.
static void importJMPDataTabletoMathematica( const char *szPath ) {
	JMPConnection		jmpConn;

	if ( !jmpConn.fileExists( szPath ) ) {
		jmpConn.sendErrorToMathematica();
		return;
	}

	if ( !jmpConn.connect() ) {
		jmpConn.sendErrorToMathematica();
		return;
	}

	if ( !jmpConn.openDT( szPath ) ) {
		jmpConn.sendErrorToMathematica();
		jmpConn.quit();
		return;
	}

	if ( !jmpConn.sendDTToMathematica() ) {
		jmpConn.sendErrorToMathematica();
		jmpConn.quit();
		return;
	}

	jmpConn.quit();

	return;
}


//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//		Interface between JMPImport and JMP
//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
JMPConnection::JMPConnection() : m_DispDriver(0), m_bConnected(FALSE) {
	m_error = 0;
}

JMPConnection::~JMPConnection() {}

//Check if file exists
BOOL JMPConnection::fileExists( const char *szPath ) {
	CFileStatus status;
	if( CFile::GetStatus( szPath, status )==0 ) {
		m_error = eJMPConnErrFileDNE;
		return FALSE;
	}
	return TRUE;
}

//Keep track of whether we've already initialized OLE.  This needs to be done once
//and ONLY once for the entire life of our app.
static BOOL bOLEWasInitialized = FALSE; //FixMe: This variable should be a member of the app

//initializeOLE() should be called at the time our app starts up.
//At present, we call it from WinMain in MathLinkConnection.cpp before we call MLMain.
//This routine needs to be called, in order for us to make an OLE Automation
//connection to JMP.
BOOL initializeOLE(void) {
    if ( bOLEWasInitialized ) return TRUE;  //We've already initialized OLE, so avoid doing it again.
	// Initialize OLE libraries -- Must be done when invoked via MathLink, but not when running standalone
	CoInitialize( NULL );
	if (!AfxOleInit()) {
		//AfxMessageBox("Unable to initialize OLE Automation");
		return FALSE;
	}
	//AfxMessageBox("AfxOleInit succeeded");
	bOLEWasInitialized = TRUE;
    return TRUE;
}

//unInitializeOLE() should be called at the time our app shuts down.
//At present, it is being called from WinMain after MLMain returns.
//It doesn't seem to do any harm to NOT call AfxOleTerm() and CoUninitialize()
//at app shutdown (famous last words), but just to be safe, we do so.
void unInitializeOLE(void) {
    if ( !bOLEWasInitialized ) return;
    AfxOleTerm(FALSE);
    CoUninitialize();
}

//Establish an OLE Automation connection to JMP
BOOL JMPConnection::connect(  void ) {
	if ( !bOLEWasInitialized ) return FALSE;

	//Create the initial dispatch driver that uses the IJMPAutoApp interface specification.
    //AfxMessageBox("Starting JMP");
	COleException error;
	if ( !m_DispDriver.CreateDispatch("JMP.Application", &error ) ) {
		m_error = eJMPConnErrUnableToConnect;
		//UINT	nMaxError = 512;
		//char	szError[512];
		//error.GetErrorMessage( szError, nMaxError );
		//AfxMessageBox( szError, MB_OK );
		return FALSE;
	}
	if (m_DispDriver.m_lpDispatch == NULL) {
		m_error = eJMPConnErrUnableToConnect;
		return FALSE;
	}

	m_bConnected = TRUE;

	//We successfully started JMP.  Make it hidden.  Otherwise the user will see a brief
	//flash as JMP comes up, opens the file, and then disappears.
	m_DispDriver.SetVisible(FALSE);

	return TRUE;
}

//Open a file given by szPathToFile as a JMP data table.
//For a file ending with the ".JMP" extension, the document
//interface pointer that we receive after asking our m_DispDriver
//member to open the file is attached to our m_Doc member, which
//instantiates the IJMPDoc interface.  The data table object it
//encapsulates is then attached to our m_DT member, which instantiates
//the IAutoDataTable interface.  Using the m_DT member, we can access
//the data contained within the JMP data table.
//If the input path does not designate a JMP file, we tell our m_DispDriver member
//to ask JMP to import it using the JSL "open" command.  This allows us to open
//SAS data sets, among other file types. Unforunately, if the input path does
//not point to a file type that JMP recognizes,this generates an unhandled error
//within Mathematica.
//It is assumed that the input path is valid and points to an existing file.
BOOL JMPConnection::openDT( const char *szPathToFile ) {
	CString		cstrFile(szPathToFile);
	if ( cstrFile.Right(4).MakeLower()== ".jmp" ) {
		//AfxMessageBox("Attempting to attach doc");
		m_Doc.AttachDispatch(m_DispDriver.OpenDocument( szPathToFile ));
		if (m_Doc.m_lpDispatch==NULL) {
			//AfxMessageBox("Unable to open doc");
			m_error = eJMPConnErrUnableToOpenDT;
			return FALSE;
		}

		//Set the Title of the opened document
		m_Doc.SetName("JMPImport Data Table");
		//Now get the DataTable from the open document.
		//AfxMessageBox("Attempting to attach dt");
		m_DT.AttachDispatch(m_Doc.GetDataTable());
		if ( m_DT.m_lpDispatch == NULL ) {
			//AfxMessageBox("Unable to attach dt");
			m_error = eJMPConnErrUnableToOpenDT;
			return FALSE;
		}
		return TRUE;
	}

	//Let's see if JMP can import it using the JSL "open" command.
	//The JSL "open" command will call the JMP Import facility to try to
	//import the file as a JMP data table (assuming JMP recognizes the file
	//extension and knows how to open such files).
	CString		cstrJSLScript;
	cstrJSLScript.Format("open(\"%s\")", szPathToFile );

	//CString		cstrInfoFileToBeOpened;
	//cstrInfoFileToBeOpened.Format("Opening file.  JSL script: %s", cstrJSLScript );
	//AfxMessageBox(cstrInfoFileToBeOpened);

	//Submit the JSL script to JMP
	m_DispDriver.RunCommand( cstrJSLScript );

	//What type of file is it?
	BOOL	bIsSASDataSet = (cstrFile.Right(9).MakeLower() == ".sas7bdat") ? TRUE : FALSE;

	if ( m_DispDriver.GetNumberOfAutomationDatatables()==0 ){
		//AfxMessageBox(" m_DispDriver.GetNumberOfAutomationDatatables()==0");
		m_error = bIsSASDataSet ? eJMPConnErrUnableToOpenSASDS : eJMPConnErrUnableToOpenFile;
		return FALSE;
	}
	LPDISPATCH	lpDispatch = m_DispDriver.GetTableHandleFromIndex(1);
	if ( lpDispatch==NULL ) {
		//AfxMessageBox(" m_DispDriver.GetTableHandleFromIndex(1)==NULL");
		m_error = bIsSASDataSet ? eJMPConnErrUnableToOpenSASDS : eJMPConnErrUnableToOpenFile;
		return FALSE;
	}
	m_DT.AttachDispatch( lpDispatch );
	if (m_DT.m_lpDispatch==NULL) {
		//AfxMessageBox("Unable to attach table to m_DT");
		m_error = bIsSASDataSet ? eJMPConnErrUnableToOpenSASDS : eJMPConnErrUnableToOpenFile;
		return FALSE;
	}
	LPDISPATCH	lpDispatchDoc = m_DT.GetDocument();
	if ( lpDispatchDoc != NULL ) { //it's not the end of the world if we can't obtain this handle
		m_Doc.AttachDispatch(lpDispatchDoc);
		if (m_Doc.m_lpDispatch != NULL) {
			//Set the Title of the opened document
			CString	cstrTitle;
			cstrTitle.Format("JMPImport %s", bIsSASDataSet ? "SAS Data Set" : "Data File" );
			m_Doc.SetName(cstrTitle);
		}
	}
	return TRUE;
}

//Terminate our OLE Automation connection with JMP.
//Among other things, this tells JMP to shut down.
void JMPConnection::quit(void) {
    //AfxMessageBox("JMPConnection::quit called", MB_OK);
	if ( !bOLEWasInitialized ) return;

	if ( !m_bConnected ) return;

    //AfxMessageBox("JMPConnection::quit preparing to release dispatches", MB_OK);
	if ( m_DT.m_lpDispatch != NULL )
		m_DT.ReleaseDispatch();

	if ( m_Doc.m_lpDispatch !=NULL )
	    m_Doc.ReleaseDispatch();

	if ( m_DispDriver.m_lpDispatch != NULL ) {
		m_DispDriver.Quit();  //Issue the Quit command to JMP

		m_DispDriver.ReleaseDispatch();
	}
    //AfxMessageBox("JMPConnection::quit returning", MB_OK);
}



//Use stdlink connection to send the data from the current JMP data table to Mathematica.
//It is assumed that JMP has already opened a data file.
BOOL JMPConnection::sendDTToMathematica(void) {
    if ( !m_bConnected ) return FALSE;

    //AfxMessageBox( "sendDTToMathematica called", MB_OK );
    long    nRows = m_DT.GetNumberRows();
    long    nCols = m_DT.GetNumberColumns();
    if ( nRows==0 || nCols==0 ) {//return an empty List to Mathematica
        MLPutFunction( stdlink, "List", 0 );
		MLEndPacket( stdlink);
        return TRUE;
    }
    //CString     csDTInfo;
    //csDTInfo.Format("calling MLPutFunction: nRows==%d nCols==%d", nRows, nCols );
    //AfxMessageBox( csDTInfo, MB_OK );
    //send a new list to Mathematica to represent the data table
    if ( MLPutFunction( stdlink, "List", nRows+1 )==0 ) {//add 1 to account for list of columns
        m_error = eJMPConnErrUnableToImportDT;
        return FALSE;
    }

    //AfxMessageBox( "sending data to Mathematica", MB_OK );

    IAutoColumn     *column = NULL;
    try {
        column = new IAutoColumn[nCols];
        if ( column==NULL ) {
            //AfxMessageBox("Unable to allocate memory for IAutoColumn array");
			m_error = eJMPConnErrUnableToAllocMem;
            throw;
        }
		//send a new list to Mathematica for the set of column names
		if ( MLPutFunction( stdlink, "List", nCols )==0 ) {
			//AfxMessageBox("Unable to create new List");
			m_error = eJMPConnErrUnableToImportDT;
			throw;
		}
        for( long colIndex=0; colIndex < nCols; colIndex++ ) {
            LPDISPATCH  _colDispatch = m_DT.GetColumnByIndex(colIndex+1);//columns are numbered starting with 1
            if ( _colDispatch==NULL ) {
                //AfxMessageBox("Unable to obtain _colDispatch");
				m_error = eJMPConnErrUnableToImportDT;
                throw;
            }
            column[colIndex].AttachDispatch(_colDispatch);
            if ( column[colIndex].m_lpDispatch==NULL ) {
                //AfxMessageBox("Unable to Attach Dispatch");
				m_error = eJMPConnErrUnableToImportDT;
                throw;
            }
			CString     cstrColumnName =  column[colIndex].GetName();
			MLPutString( stdlink, cstrColumnName.GetBuffer() );
        }

		//now send each row of data
        for( long nRowNum=1; nRowNum <= nRows; nRowNum++ ) {//rows are numbered starting at 1
            //CString     csRowMsg;
            //csRowMsg.Format("Sending row #%d", nRowNum );
            //AfxMessageBox(csRowMsg, MB_OK);

            //send a new list to Mathematica for the current row of data
            if ( MLPutFunction( stdlink, "List", nCols )==0 ) {
                m_error = eJMPConnErrUnableToImportDT;
                throw;
            }

            for( long colIndex=0; colIndex < nCols; colIndex++ ) {
                //CString     csColMsg;
                //csColMsg.Format("Getting dispatch for col #%d", colIndex );
                //AfxMessageBox(csColMsg, MB_OK);

                CString     cstrCellValue =  column[colIndex].GetCellVal(nRowNum);

                //CString     cstrTypeMsg;
                //cstrTypeMsg.Format("col #%d type == %d", colIndex, _COL.GetDataType());
                //AfxMessageBox(cstrTypeMsg, MB_OK);

                //Note: column[colIndex].GetDataType() returns:
                //type==1 ==> numeric
				//type==2 ==> character
				if ( column[colIndex].GetDataType()==1 ) {
					if ( cstrCellValue=="." ) {
						//AfxMessageBox("output missing to stdlink");
						MLPutFunction( stdlink, "Missing",0);
						//AfxMessageBox("return - output missing to stdlink");
					}
					else {
						char * pEnd;
						//AfxMessageBox("call strtod");
						double dVal = strtod( cstrCellValue.GetBuffer(), &pEnd );
						//AfxMessageBox("output dVal to stdlink");
						MLPutDouble( stdlink, dVal );
						//AfxMessageBox("return - output dVal to stdlink");
					}
				}
				else {
					MLPutString( stdlink, cstrCellValue.GetBuffer() );
				}
            }
        }
    }
    catch(...) {
        if ( column!=NULL ) {
            for( long colIndex=0; colIndex < nCols; colIndex++ ) {
                column[colIndex].ReleaseDispatch();
            }
            delete[] column;
        }
        return FALSE;
    }
    
    for( long colIndex=0; colIndex < nCols; colIndex++ ) {
        column[colIndex].ReleaseDispatch();
    }
    delete[] column;

    //AfxMessageBox("Preparing to call MLEndPacket and MLFlush");

    MLEndPacket( stdlink); //close off the list representing the data table
    MLFlush( stdlink );

    //AfxMessageBox("MLEndPacket and MLFlush called");

    return TRUE;
}

//In case we encounter an error, we call this routine to send a message back to
//Mathematica.  The text of the errror messages is provided in our JMPImport.tm file.
void JMPConnection::sendErrorToMathematica( void ) {
	CString		cstrWhichError;
	switch( m_error ) {
	case eJMPConnErrFileDNE:
		cstrWhichError = "fileDNE";
		break;
	case eJMPConnErrUnableToConnect:
		cstrWhichError = "unableToConnect";
		break;
	case eJMPConnErrUnrecognizedFileType:
		cstrWhichError = "unrecognizedFileType";
		break;
	case eJMPConnErrUnableToOpenDT:
		cstrWhichError = "unableToOpenDT";
		break;
	case eJMPConnErrUnableToOpenSASDS:
		cstrWhichError = "unableToOpenSASDS";
		break;
	case eJMPConnErrUnableToOpenFile:
		cstrWhichError = "unableToOpenFile";
		break;
	case eJMPConnErrUnableToImportDT:
		cstrWhichError = "unableToImportDT";
		break;
	case eJMPConnErrUnableToAllocMem:
		cstrWhichError = "unableToAllocMem";
		break;
	default:
		cstrWhichError = "unknownError";
		break;
	}
	CString		cstrError;
	cstrError.Format("Message[JMPImport::%s]", cstrWhichError );
	MLEvaluate(stdlink, cstrError.GetBuffer() );
	MLNextPacket(stdlink);
	MLNewPacket(stdlink);
	MLPutSymbol(stdlink, "$Failed");
}
